;******************************************************************************
; AUTOHOTKEY SCRIPT FOR USING ORTEK VRC-1100 REMOTE CONTROL WITH MEDIAPORTAL
;
; Author:   CyberSimian (contact via fora at: www.team-mediaportal.com)
; Version:  2016-01-14
;
; o  The Ortek remote control is sold under the following brand names:
;    -  Adesso ARC-1100
;    -  Auvisio VRC-1100
;    -  Gmyle
;    -  Hama 00052451
;    -  Ortek VRC-1100
;    -  Sanoxy VRC-1100
;
; o  This script remaps several of the buttons on the Ortek remote control to
;    give improved functionality. The following buttons are changed:
;
;    BROWSER-HOME
;    Normally this button invokes the default web browser and displays the
;    user's home page.  To perform this function, Windows intercepts the
;    button before it is received by Centarea HID.  As a result, "Centarea
;    HID.xml" cannot be used to redefine the button.  Instead, this script
;    should be used.
;      The default mapping defined in this script changes BROWSER-HOME so
;    that it displays the MediaPortal "Home" panel (keyboard shortcut "h"),
;    but this can be changed to perform some other function, or the line can
;    be commented out if the original function is required (place a semicolon
;    character at the start of the line to turn the line into a comment).
;
;    LEFT-MOUSE
;    This button is changed so that it toggles the MediaPortal Context menu
;    (keyboard shortcut "F9").  This change occurs only when the mouse
;    pointer is within a MediaPortal window.
;
;    RIGHT-MOUSE
;    This button is changed so that it toggles the MediaPortal OSD (keyboard
;    shortcut "y").  This change occurs only when the mouse pointer is within
;    a MediaPortal window.
;      Note:  on the author's system there is a perceptible pause between
;    pressing the button to remove the OSD, and the OSD actually disappearing
;    (about 2 seconds).  It is not known what causes this.
;
;    INFO ("I")
;    This button is a duplicate of the RIGHT-MOUSE button: the Ortek
;    transmits the same signal for both.  As a result, it is not possible to
;    define different actions for these buttons -- INFO will always perform
;    the same action as RIGHT-MOUSE.
;
;    START
;    This button is changed as follows:
;    -  If MediaPortal is not running, it is started and given the focus.
;       This allows MediaPortal to be started from the desktop.  The "MPTray"
;       application that is usually used to start MediaPortal from the
;       desktop does not work with the Ortek remote control, so this script
;       is a replacement for that.
;         Very occasionally MediaPortal does not terminate completely (some
;       part of it remains loaded), and this prevents MediaPortal restarting.
;       To bypass this problem, this script uses the TASKKILL command to
;       terminate MediaPortal before restarting MediaPortal.  Note that this
;       causes a command window to appear on the screen for a second or two.
;    -  If MediaPortal is running but does not have the focus, it is given the
;       focus.
;    -  If MediaPortal is running and has the focus, the MediaPortal "Home"
;       panel is displayed.
;
; o  To use this script:
;    -  Download AutoHotKey and install it.  AutoHotKey can be found here:
;         https://www.autohotkey.com/
;       The author uses AutoHotKey version 1.0.48.05 on 32-bit Windows Vista,
;       and this has proved entirely satisfactory.
;    -  In the script below, modify the path that specifies the location of
;       "MediaPortal.exe" so that it corresponds to the location on your
;       system.
;    -  Use "Windows Explorer" to navigate to this script and then double-
;       click it (or single-click if you have defined your system that way).
;       The script should now be running.  A green icon with an "H" symbol
;       should appear towards the right-hand end of the Task Bar.
;    -  To stop using the script, right-click the green "H" icon in the Task
;       Bar, and select "Exit".
;    -  If you decide that you want to use this script permanently, copy the
;       script into your "Startup" folder, where it will autostart whenever
;       you boot your system.
;
; o  AutoHotKey scripts use the following notation:
;      ; == comment line
;      ! == ALT key
;      ^ == CTRL key
;      + == SHIFT key
;      # == WINDOWS key
;
;
;******************************************************************************
; INITIALISATION (AUTO-EXECUTE SECTION; EXECUTED ONCE-ONLY)
;
; Window-title match mode (1=match start, 2=match substring, 3=match exactly)
  SetTitleMatchMode, 2
;
; Specify the windows where mapping is to occur.
; Mapping occurs in windows that have "MediaPortal in the name, but which do
; not have "Configuration" in the name. This EXCLUDES the following windows:
; -  "MediaPortal - Configuration"
; -  "MediaPortal - TV Server Configuration"
; Note: parameters 2 and 5 obey "SetTitleMatchMode".
  GroupAdd, mpwin, MediaPortal, , , Configuration,
  GroupAdd, mpwin, MediaPortal, , , Setup,
;
  return
;
;
;******************************************************************************
; MAPPINGS FOR WHEN MEDIAPORTAL IS NOT RUNNING
;
  #IfWinNotExist, ahk_group mpwin
;
; START button
; We use "taskkill" to terminate "MediaPortal.exe", in case MediaPortal did not
; stop cleanly when closed previously. This happens sometimes, and it prevents
; MediaPortal restarting.
  #!enter::
; Note: the first two versions of the "runwait" command do not work correctly!
;   runwait, taskkill.exe /f /im MediaPortal.exe 1>nul 2>nul, , hide
;   runwait, taskkill.exe /f /im MediaPortal.exe & wait.exe 10, ,
    runwait, taskkill.exe /f /im MediaPortal.exe            , ,
; Wait for "taskkill" command to complete (value is milliseconds).
    sleep, 500
; Start MediaPortal.
; Change path in next line to the location where "MediaPortal.exe" resides.
    run, "C:\Program Files\Team MediaPortal\MediaPortal\MediaPortal.exe"
    return
;
;
;******************************************************************************
; MAPPINGS FOR WHEN MEDIAPORTAL IS RUNNING BUT DOES NOT HAVE THE FOCUS
;
  #IfWinNotActive, ahk_group mpwin
;
; START button
  #!enter::WinActivate, ahk_group mpwin
;
;
;******************************************************************************
; MAPPINGS FOR WHEN MEDIAPORTAL IS RUNNING AND DOES HAVE THE FOCUS
;
  #IfWinActive, ahk_group mpwin
;
; BROWSER-HOME button
  browser_home::h
;
; LEFT-MOUSE button
  lbutton::
    MouseGetPos, , , id,
    WinGetTitle, title, ahk_id %id%
    IfInString, title, MediaPortal
    {
      IfInString, title, Configuration
        sendinput {lbutton}
      else IfInString, title, Setup
        sendinput {lbutton}
      else
        sendinput {f9 down}{f9 up}
    }
    else
      sendinput {lbutton}
    return
;
; RIGHT-MOUSE button
  rbutton::
    MouseGetPos, , , id,
    WinGetTitle, title, ahk_id %id%
    IfInString, title, MediaPortal
    {
      IfInString, title, Configuration
        sendinput {rbutton}
      else IfInString, title, Setup
        sendinput {rbutton}
      else
        sendinput {y down}{y up}
    }
    else
      sendinput {rbutton}
    return
;
; START button
; The START button generates the following sequence of keystrokes:
; -  press and hold WINDOWS key
; -  press and hold ALT key
; -  (press RETURN key)  (not detected)
; -  release ALT key
; -  release WINDOWS key
; -  release RETURN key
  #!enter::sendinput {lwin up}{alt up}{h down}{h up}{alt down}{lwin down}
;
;
;******************************************************************************
